# Generated by Django 3.2.13 on 2022-06-03 13:07

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('authentication', '0019_merge_20211026_0919'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('industry', '0003_auto_20220601_1747'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserCharacters',
            fields=[
                ('character_ownership', models.OneToOneField(help_text='ownership of this character on Auth', on_delete=django.db.models.deletion.CASCADE, primary_key=True, related_name='industry_character', serialize=False, to='authentication.characterownership')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'User x Characters',
                'verbose_name_plural': 'User x Characters',
                'ordering': ['user'],
            },
        ),
    ]
