{% extends 'allianceauth/base.html' %} {% load i18n %} {% block page_title %}
    {% translate "Industry" %}{% endblock %} {% block content %}
<div class="allianceauth-industry-plugin">
  <h1 class="page-header text-center">
      {% translate "The Industry Plugin" %}
  </h1>

  {% block details %}{% endblock %}
</div>
{% endblock %}
