# from django.conf import settings

# put your app settings here, like this
# (And don't forget to uncomment the import above):

# EXAMPLE_SETTING_ONE = getattr(settings, "EXAMPLE_SETTING_ONE", None)
