# Generated by Django 3.2.13 on 2022-06-01 17:47

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ('eveuniverse', '0007_evetype_description'),
        ('industry', '0002_delete_usertoken'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='facility',
            name='solar_system_id',
        ),
        migrations.AddField(
            model_name='facility',
            name='solar_system',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE,
                                    to='eveuniverse.evesolarsystem'),
        ),
    ]
