# Generated by Django 3.2.13 on 2022-06-01 17:09

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('industry', '0001_initial'),
    ]

    operations = [
        migrations.DeleteModel(
            name='UserToken',
        ),
    ]
