# Generated by Django 3.2.13 on 2022-05-27 16:43

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('esi', '0011_add_token_indices'),
    ]

    operations = [
        migrations.CreateModel(
            name='Facility',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('facility_id', models.BigIntegerField(verbose_name='Facility')),
                ('name', models.CharField(max_length=2048, verbose_name='Name')),
                ('owner_id', models.BigIntegerField(verbose_name='Owner Id')),
                ('solar_system_id', models.BigIntegerField(verbose_name='Solar System Id')),
                ('type_id', models.BigIntegerField(verbose_name='Type')),
            ],
            options={
                'verbose_name': 'Facility',
                'verbose_name_plural': 'Facilities',
                'ordering': ['name'],
            },
        ),
        migrations.CreateModel(
            name='Industry',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
        ),
        migrations.CreateModel(
            name='UserToken',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('character_id', models.IntegerField(db_index=True, help_text='The ID of the EVE character who authenticated by SSO.')),
                ('token', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='esi.token')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'Industry User x Token',
                'verbose_name_plural': 'Industry User x Tokens',
                'ordering': ['user'],
            },
        ),
    ]
