{% extends './base.html' %} {% load i18n %} {% load humanize %} {% block details %}

<div class="panel panel-primary">
    <div class="panel-heading">
        <h3 class="panel-title">Industry Form - Do you really want to delete the character:</h3>
    </div>
    <div class="panel-body">
        <table class="table table-striped table-hover table-aa">
            <thead>
            <tr>
                <th scope="col" class="table-center">Photo</th>
                <th scope="col" class="table-center">Name</th>
            </tr>
            </thead>
            <tbody>
            <tr>
                <td class="table-center">
                    <img class="margin-right-md" src="https://images.evetech.net/characters/{{ usertoken.character_id }}/portrait?size=64">
                </td>
                <td class="table-center">{{ usertoken.token.character_name }}</td>
            </tr>
            </tbody>
        </table>
    </div>

    <div class="">
        <form action="." method="POST">{% csrf_token %}
            <div class="action-links">
                <button type="submit" class="btn btn-danger action-padding">Delete</button>
                <a href="{% url 'industry:list_jobs' usertoken.pk %}" class="btn btn-success action-padding">Cancel</a>
            </div>
        </form>
    </div>

</div>

{% endblock %}

{% block extra_css %}
<style>
.table-center {
    text-align: center;
}

.action-links {
    display: flex;
    justify-content: center;
    margin: 0 0 10px 0;
    grap: 10px;
}

.action-padding {
    margin-right: 15px;
    margin-left: 15px;
}

</style>
{% endblock %}