
<tr>
    <td class="table-center">
        {{ forloop.counter }}
    </td>

    <td class="table-center">{{ i.station_name }}</td>

    <td class="">
        <!-- to_screen['corporation_job'] = is_corp -->
        <img class="rounded-full w-16" src="https://images.evetech.net/characters/{{ i.installer_id }}/portrait?size=32">
        <img src="https://image.eveonline.com/Type/{{ i.blueprint_id }}_32.png">
        <span style="margin-left: 5px">{{ i.blueprint_name }}</span>
    </td>

    <td class="table-center">
        <div class="progress table-vertical-align" style="height: 35px; width: 150px">
            {% if i.status == 'active' %}
            <div id="progress_{{ i.blueprint_id }}"
                 class="progress-bar progress-bar-success progress-bar-striped active"
                 role="progressbar" aria-valuenow="70"
                 aria-valuemin="0" aria-valuemax="100">
                    <div class="progress-bar-custom">0%</div>
            </div>
            {% else %}
            <div id="progress_{{ i.blueprint_id }}"
                 class="progress-bar progress-bar-danger progress-bar-striped"
                 role="progressbar" aria-valuenow="100"
                 aria-valuemin="0" aria-valuemax="100">
                    <div class="progress-bar-custom">100%</div>
            </div>
            {% endif %}
        </div>
    </td>

    {% if i.status == 'active' %}
        <td class="table-center" id="remaining_{{ i.blueprint_id }}">
    {% else %}
        <td class="table-center" id="remaining">
    {% endif %}

        </td>

    <td class="table-center">{{ i.duration }}</td>

    <td class="table-center" id="start_date_{{ i.blueprint_id }}">
        {{ i.start_date | date:"Y-m-d H:i" }}
    </td>
    <td class="table-center" id="end_date_{{ i.blueprint_id }}">
        {{ i.end_date |date:"Y-m-d H:i" }}
    </td>
    <input type="hidden" name="timeleft" value="{{ i.blueprint_id }}" />
</tr>
